#your data DMSO1 (LatB roots - 42 s data)
#time
x<-c(-44,-43,-42,-41,-40,-39,-38,
     -37,-36,-35,-34,-33,-32,-31,-30,-29,-28,-27,-26,-25,-24,-23,-22,-21,-20,-19,-18,-17,-16,-15,-14,-13,
     -12,-11,-10,-9,-8,-7,-6,-5,-4,-3,-2,-1,0)
#intensity
y<-c(0.6137539,0.6149551,0.6081846,0.6130507,0.62028956,0.7347557,0.7407102,0.75036216,0.7923313,0.85433817,0.852398,
     0.88818455,0.88955367,0.92815554,0.92777485,0.8823415,1.000000,0.99251133,0.9163246,0.9431744,
     0.9465064,0.95352197,0.9407634,0.927775,0.98412967,0.9791237,0.8915277,0.93315226,0.9258151,0.89272267,
     0.91828156, 0.87510085,0.87791234,0.8698811,0.85228884,0.83197826,0.872572,0.83867687,0.800206,
     0.8014717,0.7686676,0.73892206,0.67106575,0.6055914,0.709106) 

library(splines)
spline <- interpSpline(x,y)
plot(spline)
points(x,y)

library(ggplot2)
df<-as.data.frame(cbind(x,y))
g<-ggplot(df,aes(x,y))+stat_smooth(method="loess")+geom_smooth(method="loess")

fit<-loess(y~x,data=df)
#y predictions with loess fit in range of x
x.range<-min(df$x):max(df$x)
df$pred.y<-predict(fit,x.range)

#par(mfrow=c(3,1))
plot(df$x,df$y,main="original data")
plot(df$x,df$pred.y,main="loess prediction")


#first derivative is the slope (diff is pretty close)
slopes <- diff(df$pred.y)
#different lengths, let's just get rid of one point, let's say the last one
df<-df[-nrow(df),]
df$slopes<-slopes

plot(df$x,df$slopes,main="slopes")
abline(h=0,lwd=1,lty=2) #line at zero

#if first derivative is positve your intensity is growing
#if it's zero it's flattening
#if it's negative it is shrinking

#where is the slope closest to zero? peak
peak<-which.min(abs(slopes - 0))  
peak # 20th point of this dataset

df[20,] 

#     x         y    pred.y        slopes
# 20 -25 0.9431744 0.9572674 -0.0004020335

#we need a scale (to be able to figure out what 20% of it is)
#split curve into before peak and after peak

left<-df[1:peak,]
right<-df[peak:nrow(df),]

#we use quantiles

#for the left side of the curve  # threshold 20% of the minimum
minl<-df$slopes[peak]

maxl<-max(left$slopes[1:(peak)])
lseq<-seq(minl,maxl,by=(maxl-minl)/100)
thrl<-quantile(lseq,0.2)
thr_x_left<-df$x[which.min(abs(df$slopes - thrl))]

#for the right side of the curve
maxr<-df$slopes[peak]
minr<-min(right$slopes)
rseq<-seq(minr,maxr,by=(maxr-minr)/100)
thrr<-quantile(rseq,0.8) 
thr_x_right<-df$x[which.min(abs(df$slopes - thrr))]

# we see how this thresholds look
#dev.off()
plot(df$x,df$y,main="original data",axes=FALSE)
axis(side=1, at=c(-44:0))
axis(side=2, at=seq(0.0, 1.0, by=0.1))
box()
abline(v=thr_x_left);abline(v=thr_x_right);abline(v=df$x[peak])
plot(spline)
points(x,y)
abline(v=thr_x_left);abline(v=thr_x_right);abline(v=df$x[peak])
plot(df$x,df$pred.y,main="loess prediction")
abline(v=thr_x_left);abline(v=thr_x_right);abline(v=df$x[peak])
plot(df$x,df$slopes,main="slopes")

abline(h=0,lwd=1,lty=2) #line at zero
abline(v=thr_x_left);abline(v=thr_x_right);abline(v=df$x[peak])

thr_x_right # phase transition from assembly
thr_x_left  # phase transition to scisison

## (-20,-28)

#here is how quantiles work just to check
#if you have a range of slopes, from 0.0007 to 0.18
s<-seq(0.0007,18,by=(18-0.0007)/100)
plot(s)
abline(h=quantile(s,0.2))
abline(h=quantile(s,0.5))
