#your data DMSO3 (LatB roots - 42 s data)
#time
x<-c(-44,-43,-42,-41,-40,-39,-38,
     -37,-36,-35,-34,-33,-32,-31,-30,-29,-28,-27,-26,-25,-24,-23,-22,-21,-20,-19,-18,-17,-16,-15,-14,-13,
     -12,-11,-10,-9,-8,-7,-6,-5,-4,-3,-2,-1,0)
#intensity
y<-c(0.4281331,
     0.5426324,
     0.590681,
     0.6341586,
     0.5664532,
     0.6015776,
     0.6334046,
     0.6485499,
     0.7136691,
     0.7861007,
     0.7811235,
     0.7713969,
     0.8118402,
     0.842557,
     0.8694269,
     0.8771892,
     0.9115468,
     0.908887,
     0.9510698,
     0.9573693,
     0.9570051,
     0.9351903,
     0.950919,
     0.9645613,
     0.9489983,
     1.000000,
     0.9564356,
     0.9607476,
     0.968415,
     0.9612957,
     0.9482111,
     0.9205858,
     0.9051366,
     0.9235084,
     0.9246075,
     0.8980604,
     0.830769,
     0.7998021,
     0.8081292,
     0.7589376,
     0.7083114,
     0.6906242,
     0.6587843,
     0.6323425,
     0.5951344) 

library(splines)
spline <- interpSpline(x,y)
plot(spline)
points(x,y)

library(ggplot2)
df<-as.data.frame(cbind(x,y))
g<-ggplot(df,aes(x,y))+stat_smooth(method="loess")+geom_smooth(method="loess")

fit<-loess(y~x,data=df)
#y predictions with loess fit in range of x
x.range<-min(df$x):max(df$x)
df$pred.y<-predict(fit,x.range)

#par(mfrow=c(3,1))
plot(df$x,df$y,main="original data")
plot(df$x,df$pred.y,main="loess prediction")


#first derivative is the slope (diff is pretty close)
slopes <- diff(df$pred.y)
#different lengths, let's just get rid of one point, let's say the last one
df<-df[-nrow(df),]
df$slopes<-slopes

plot(df$x,df$slopes,main="slopes")
abline(h=0,lwd=1,lty=2) #line at zero

#if first derivative is positve your intensity is growing
#if it's zero it's flattening
#if it's negative it is shrinking

#where is the slope closest to zero? peak
peak<-which.min(abs(slopes - 0))  
peak # 26th point of this dataset

df[26,] 

#     x y    pred.y        slopes
# 26 -19 1 0.9711494 -0.0007581719

#we need a scale (to be able to figure out what 20% of it is)
#split curve into before peak and after peak

left<-df[1:peak,]
right<-df[peak:nrow(df),]

#we use quantiles

#for the left side of the curve  # threshold 20% of the minimum
minl<-df$slopes[peak]

maxl<-max(left$slopes[1:(peak)])
lseq<-seq(minl,maxl,by=(maxl-minl)/100)
thrl<-quantile(lseq,0.2)
thr_x_left<-df$x[which.min(abs(df$slopes - thrl))]

#for the right side of the curve
maxr<-df$slopes[peak]
minr<-min(right$slopes)
rseq<-seq(minr,maxr,by=(maxr-minr)/100)
thrr<-quantile(rseq,0.8) 
thr_x_right<-df$x[which.min(abs(df$slopes - thrr))]

# we see how this thresholds look
#dev.off()
plot(df$x,df$y,main="original data",axes=FALSE)
axis(side=1, at=c(-44:0))
axis(side=2, at=seq(0.0, 1.0, by=0.1))
box()
abline(v=thr_x_left);abline(v=thr_x_right);abline(v=df$x[peak])
plot(spline)
points(x,y)
abline(v=thr_x_left);abline(v=thr_x_right);abline(v=df$x[peak])
plot(df$x,df$pred.y,main="loess prediction")
abline(v=thr_x_left);abline(v=thr_x_right);abline(v=df$x[peak])
plot(df$x,df$slopes,main="slopes")

abline(h=0,lwd=1,lty=2) #line at zero
abline(v=thr_x_left);abline(v=thr_x_right);abline(v=df$x[peak])

thr_x_right # phase transition from assembly
thr_x_left  # phase transition to scisison

## (-15,-23)

#here is how quantiles work just to check
#if you have a range of slopes, from 0.0007 to 0.18
s<-seq(0.0007,18,by=(18-0.0007)/100)
plot(s)
abline(h=quantile(s,0.2))
abline(h=quantile(s,0.5))
