#your data DMSO5 (LatB roots - 42 s data)
#time
x<-c(-44,-43,-42,-41,-40,-39,-38,
     -37,-36,-35,-34,-33,-32,-31,-30,-29,-28,-27,-26,-25,-24,-23,-22,-21,-20,-19,-18,-17,-16,-15,-14,-13,
     -12,-11,-10,-9,-8,-7,-6,-5,-4,-3,-2,-1,0)
#intensity
y<-c(0.7587973,
     0.8675814,
     0.7625381,
     0.7079955,
     0.8090577,
     0.7810974,
     0.8404962,
     0.7991159,
     0.8785412,
     0.8507188,
     0.9250979,
     0.9337141,
     0.8933764,
     0.876786,
     0.8991186,
     0.8847804,
     0.9287573,
     0.9454765,
     0.9019339,
     0.9477926,
     0.9664576,
     0.8927189,
     0.9734654,
     0.9675608,
     0.9122615,
     0.9705547,
     0.9174841,
     0.9828494,
     0.8986335,
     0.9847326,
     0.9619135,
     1.000000,
     0.9816603,
     0.9613779,
     0.9636219,
     0.9058691,
     0.9514708,
     0.9044652,
     0.9554433,
     0.9291098,
     0.8314652,
     0.8596124,
     0.8475491,
     0.927504,
     0.9252155) 

library(splines)
spline <- interpSpline(x,y)
plot(spline)
points(x,y)

library(ggplot2)
df<-as.data.frame(cbind(x,y))
g<-ggplot(df,aes(x,y))+stat_smooth(method="loess")+geom_smooth(method="loess")

fit<-loess(y~x,data=df)
#y predictions with loess fit in range of x
x.range<-min(df$x):max(df$x)
df$pred.y<-predict(fit,x.range)

#par(mfrow=c(3,1))
plot(df$x,df$y,main="original data")
plot(df$x,df$pred.y,main="loess prediction")


#first derivative is the slope (diff is pretty close)
slopes <- diff(df$pred.y)
#different lengths, let's just get rid of one point, let's say the last one
df<-df[-nrow(df),]
df$slopes<-slopes

plot(df$x,df$slopes,main="slopes")
abline(h=0,lwd=1,lty=2) #line at zero

#if first derivative is positve your intensity is growing
#if it's zero it's flattening
#if it's negative it is shrinking

#where is the slope closest to zero? peak
peak<-which.min(abs(slopes - 0))  
peak # 29th point of this dataset

df[29,] 

#     x         y    pred.y        slopes
# 29 -16 0.8986335 0.9614601 -0.0006092612

#we need a scale (to be able to figure out what 20% of it is)
#split curve into before peak and after peak

left<-df[1:peak,]
right<-df[peak:nrow(df),]

#we use quantiles

#for the left side of the curve  # threshold 20% of the minimum
minl<-df$slopes[peak]

maxl<-max(left$slopes[1:(peak)])
lseq<-seq(minl,maxl,by=(maxl-minl)/100)
thrl<-quantile(lseq,0.2)
thr_x_left<-df$x[which.min(abs(df$slopes - thrl))]

#for the right side of the curve
maxr<-df$slopes[peak]
minr<-min(right$slopes)
rseq<-seq(minr,maxr,by=(maxr-minr)/100)
thrr<-quantile(rseq,0.8) 
thr_x_right<-df$x[which.min(abs(df$slopes - thrr))]

# we see how this thresholds look
#dev.off()
plot(df$x,df$y,main="original data",axes=FALSE)
axis(side=1, at=c(-44:0))
axis(side=2, at=seq(0.0, 1.0, by=0.1))
box()
abline(v=thr_x_left);abline(v=thr_x_right);abline(v=df$x[peak])
plot(spline)
points(x,y)
abline(v=thr_x_left);abline(v=thr_x_right);abline(v=df$x[peak])
plot(df$x,df$pred.y,main="loess prediction")
abline(v=thr_x_left);abline(v=thr_x_right);abline(v=df$x[peak])
plot(df$x,df$slopes,main="slopes")

abline(h=0,lwd=1,lty=2) #line at zero
abline(v=thr_x_left);abline(v=thr_x_right);abline(v=df$x[peak])

thr_x_right # phase transition from assembly
thr_x_left  # phase transition to scisison

## (-14,-24)

#here is how quantiles work just to check
#if you have a range of slopes, from 0.0007 to 0.18
s<-seq(0.0007,18,by=(18-0.0007)/100)
plot(s)
abline(h=quantile(s,0.2))
abline(h=quantile(s,0.5))
