rm(list = ls())
library(ggplot2);library(tabplot); library(lme4); library(influence.ME); library(car); library(dplyr)
source('/Users/mnarasimhan/Desktop/diagnostic_functions.R', chdir = TRUE)
install.packages("car")

setwd("/Users/mnarasimhan/Documents/04 rotation/temp")

# ENDOCYTOSIS CHECK  #
data2_Axl2 = read.csv (file="P2 dendra_Axl_0803.csv",header=TRUE)
View(data2_Axl2)
#make estradiol the reference 
data2_Axl2 <- within(data2_Axl2, Treatment <- relevel(Treatment, ref = "Estradiol"))


# base plot
p2 <- ggplot(data = data2_Axl2, aes(x = Time , y = Endocytosis, group = Position))

y# facet by treatment
p2 + geom_line() + facet_grid(. ~ Treatment) 

# facet by treatment, mean values
p2+ stat_summary(aes(group = 1), geom = "point", fun.y = mean,
                 shape = 17, size = 3) + facet_grid(. ~ Treatment)


# facet by treatment, individual lines, mean loess trend(blue), 95% confidence intervals for loess smooth (shaded gray)

p2 + stat_summary(aes(group = 1), geom = "point", fun.y = mean,
                  shape = 17, size = 3) + facet_grid(. ~ Treatment) +
  stat_smooth(aes(group = 1),method="lm", se=TRUE,level=0.95) + ggtitle("PIN2 endocytosis - positive control") + xlab ("Time in min") + ylab ("Intensity in a.u")

#--- mixed model approach build model (eg. bottom up)

# linear increase of secretion
mod0<- lm  (Endocytosis ~ Time + Treatment, data=data2_Axl2)
# interaction time and treatment
mod1<- lm  (Endocytosis ~ Time * Treatment, data=data2_Axl2)
# allow random intercepts 
mod2<-lmer(Endocytosis ~ Time * Treatment + (1|Position), data=data2_Axl2)
#... arbitrary (non linear) increase of secretion
mod3<-lmer(Endocytosis ~ factor(Time) * Treatment + (1|Position), data=data2_Axl2)

summary(mod0) # treatment significantlyt influences endocytosis ->  Signif change in intercept (aov:: p- 2.69 e-10)
summary(mod1) # treatment and time interaction is NOT sgnificant -> NO Significant change in slope (aov:: p- 0.233
anova(mod1,mod0) #model with an interaction is NOT significantlyu better (p- 0.6959)

# check model quality
AIC(mod0,mod1,mod2,mod3)
BIC(mod0,mod1,mod2,mod3)

# models  get increasingly better (mod0=mod1<<mod2<mod3), but the number of parameters and complexity increases. AIC and BIC take model complexity into account. You have to do some model selection, before you proceed. I tend to go for the simplest "good enough" model that makes sense to me...
#--- check assumptions of your model 
# (a) residuals all have the same variance
plot(resid(mod1) ~ fitted(mod1),main="residual plot")
abline(h=0) 

# (b) checking the normality of residuals
qqnorm(resid(mod1), main="Q-Q plot for residuals")

# (c) checking the normality of Position effects
qqnorm(ranef(full02)$Position$"(Intercept)", main="Q-Q plot for the random effect" )

# The assumptions are FINE, you cannot see a pattern in (a), and NO deviation of residuals in (b).


full02 = lmer(Endocytosis ~ Treatment*Time+ (1 | Position), data = data2_Axl2) ##### the actual full model that works
red02 = lmer(Endocytosis ~ Treatment+Time+ (1 | Position), data = data2_Axl2)
anova(full02,red02,test="Chisq")

AIC(full02,mod1) #full02 is better


# the lmer model including interaction is signifcantly better (2.2e-16) than one without
# results show that interaction is significant; SLOPE IS  CHANGING; ENDOCYTOSIS RATE is different
# the model (full02) including interaction is worse than one without when tested for assumptions; qq plot shows it