# ENDOCYTOSIS CHECK  #
rm(list = ls())
library(ggplot2);library(tabplot); library(lme4); library(influence.ME); library(car); library(dplyr)
source('/Users/mnarasimhan/Desktop/diagnostic_functions.R', chdir = TRUE)
install.packages("car")

setwd("/Users/mnarasimhan/Documents/04 rotation/temp")
data_LatB = read.csv (file="P2 Dendra_LatB_2810.csv",header=TRUE)
#make LatB the reference 
data_LatB <- within(data_LatB, Treatment <- relevel(Treatment, ref = "LatB"))
data_LatB_final <- subset(data_LatB,Time>100)

# base plot
p2 <- ggplot(data = data_LatB, aes(x = Time, y = Endocytosis, group = Position))

# facet by treatment
p2 + geom_line() + facet_grid(. ~ Treatment)

# facet by treatment, mean values
p2+ stat_summary(aes(group = 1), geom = "point", fun.y = mean,
                 shape = 17, size = 3) + facet_grid(. ~ Treatment)

# facet by treatment, individual lines, mean loess trend(blue), 95% confidence intervals for loess smooth (shaded gray)
p2 + stat_summary(aes(group = 1), geom = "point", fun.y = mean,
                  shape = 17, size = 3) + facet_grid(. ~ Treatment) +
  stat_smooth(aes(group = 1),method="loess", se=TRUE,level=0.95) 


#--- mixed model approach build model (eg. bottom up)

# linear increase of secretion
mod0<- lm  (Endocytosis ~ Time + Treatment, data=data_LatB)
# interaction time and treatment
mod1<- lm  (Endocytosis ~ Time * Treatment, data=data_LatB)
# allow random intercepts 
mod2<-lmer(Endocytosis ~ Time * Treatment + (1|Position), data=data_LatB)
#... arbitrary (non linear) increase of secretion
mod3<-lmer(Endocytosis ~ factor(Time) * Treatment + (1|Position), data=data_LatB)

summary(mod0) # treatment significantlyt influences endocytosis ->  Signif change in intercept (p- 0.00698)
summary(mod1) # treatment and time interaction is NOT sgnificant -> NO Significant change in slope (p- 0.69589)
anova(mod1,mod0) #model with an interaction is NOT significantlyu better (p- 0.6959)

# check model quality
AIC(mod0,mod1,mod2,mod3)
BIC(mod0,mod1,mod2,mod3)

# models does NOT get increasingly better (mod0=mod1<mod2<mod3), but the number of parameters and complexity increases. AIC and BIC take model complexity into account. You have to do some model selection, before you proceed. I tend to go for the simplest "good enough" model that makes sense to me...

#--- check assumptions of your model 
# (a) residuals all have the same variance
plot(resid(full02) ~ fitted(full02),main="residual plot")
abline(h=0)

# (b) checking the normality of residuals
qqnorm(resid(full02), main="Q-Q plot for residuals")

# (c) checking the normality of Position effects
qqnorm(ranef(full02)$Position$"(Intercept)", main="Q-Q plot for the random effect" )

# The assumptions are FINE, you cannot see a pattern in (a), and NO deviation of residuals in (b).


full02 = lmer(Endocytosis ~ Treatment*Time+ (1 | Position), data = data_LatB) ##### the actual full model that works
red02 = lmer(Endocytosis ~ Treatment+Time+ (1 | Position), data = data_LatB)
anova(full02,red02,test="Chisq")
AIC(full02,mod1) #full02 is better
# model showing interaction is NOT signifcantly better (0.1074)
# results show that interaction not significant; SLOPE IS NOT CHANGING; ENDOCYTOSIS RATE IS CONSTANT AFTER LATB